@@ -1,7 +1,6 @@
 package Siebel::Srvrmgr::Daemon::Action::CheckComps::Server;
 
 use Moose::Role;
-use Siebel::Srvrmgr::Types;
 
 =pod
 
@@ -23,10 +22,9 @@ A string representing the name of the Siebel Server.
 =cut
 
 has name => (
-    isa      => 'NotNullStr',
+    isa      => 'Str',
     is       => 'rw',
-    required => 1,
-    reader   => 'get_name'
+    required => 1
 );
 
 =pod
@@ -37,23 +35,25 @@ An array reference with instances of classes that have the L<Siebel::Srvrmgr::Da
 
 =cut
 
-# :TODO      :24/07/2013 12:41:06:: this has to be changed to a HashRef to enable searching objects by name
-has components => (
-    isa      => 'ArrayRef[CheckCompsComp]',
-    is       => 'rw',
-    required => 1,
-    reader   => 'get_components'
-);
+has components => ( isa => 'ArrayRef', is => 'rw', required => 1 );
 
 =pod
 
 =head1 METHODS
 
-Each attribute has it's respective getter named as C<get_><attribute name>.
+One for each one of the attributes, with the same name for invocation. Those methods B<must> be overrided by the classes that applies this role or
+an exception will be raised.
+
+=cut
+
+requires 'name';
+requires 'components';
+
+=pod
 
 =head1 SEE ALSO
 
-=over
+=over 2
 
 =item *
 
@@ -67,11 +67,11 @@ L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Component>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
 
 This file is part of Siebel Monitoring Tools.
 
@@ -86,7 +86,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
 
